Package 'rk.network.graphs'

Title: RKWard Plugin Suite for generating and exporting Network Graphs. Includes SWD coloring, multiple layouts, and Graphics Device control.
Description: RKWard Plugin Suite for generating and exporting Network Graphs. Includes SWD coloring, multiple layouts, and Graphics Device control.
Authors: Alfonso Cano Robles
Maintainer: Alfonso Cano Robles <[email protected]>
License: GPL (>= 3)
Version: 0.0.1
Built: 2026-05-20 08:46:11 UTC
Source: https://github.com/AlfCano/rk.network.graphs

Help Index